@@ -52,6 +52,9 @@ val size_of_rect : rect -> size
 val string_of_rect : rect -> string
   (** Returns the string representation of the given rectangle. *)
 
+val in_rect : rect -> coord -> bool
+  (** Test if coord is within rect *)
+
 (** Horizontal alignment. *)
 type horz_alignment =
   | H_align_left
@@ -63,3 +66,12 @@ type vert_alignment =
   | V_align_top
   | V_align_center
   | V_align_bottom
+
+(** Movement directions. *)
+type 'a directions = {
+  left : 'a;
+  right : 'a;
+  up : 'a;
+  down : 'a;
+}
+
