@@ -9,8 +9,6 @@
 
 (** Unix specific functions *)
 
-open CamomileLibraryDefault.Camomile
-
 val sigwinch : int option
   (** The number of the signal used to indicate that the terminal size
       have changed. It is [None] on windows. *)
@@ -18,7 +16,7 @@ val sigwinch : int option
 val system_encoding : string
   (** The encoding used by the system. *)
 
-val parse_event : ?escape_time : float -> CharEncoding.t -> char Lwt_stream.t -> LTerm_event.t Lwt.t
+val parse_event : ?escape_time : float -> char Lwt_stream.t -> LTerm_event.t Lwt.t
   (** [parse_event encoding stream] parses one event from the given
       input stream. [encoding] is the character encoding used to
       decode non-ascii characters. It must be a converter from the
