@@ -1,7 +1,7 @@
 (*
  * lTerm_vi.ml
  * ------------
- * Copyright : (c) 2020, ZAN DoYe <zandoye@gmail.com>
+ * Copyright : (c) 2023, ZAN DoYe <zandoye@gmail.com>
  * Licence   : BSD3
  *
  * This file is a part of Lambda-Term.
@@ -242,7 +242,7 @@ module Query = struct
     let cursor= Zed_edit.cursor ctx in
     let count= Zed_lines.count lines in
     if index = Zed_lines.count lines then
-      Zed_rope.length text - 1
+      max 0 (Zed_rope.length text - 1)
     else begin
       let stop =
         if index + delta >= count then
