@@ -1,5 +1,3 @@
-open CamomileLibrary
-
 module type Type =
   sig
     type char_intf
@@ -7,8 +5,8 @@ module type Type =
     val empty_string : unit -> string_intf
     val of_char : Zed_char.t -> char_intf
     val of_string : Zed_string.t -> string_intf
-    val to_char : char_intf -> Zed_char.t option * UChar.t list
-    val to_string : string_intf -> Zed_string.t * UChar.t list
+    val to_char : char_intf -> Zed_char.t option * Uchar.t list
+    val to_string : string_intf -> Zed_string.t * Uchar.t list
     val to_char_exn : char_intf -> Zed_char.t
     val to_string_exn : string_intf -> Zed_string.t
   end
@@ -17,7 +15,7 @@ module Zed : Type
   with type char_intf= Zed_char.t
   and type string_intf= Zed_string.t =
 struct
-  external id : 'a -> 'a = "%identity"
+  let id x = x
   type char_intf= Zed_char.t
   type string_intf= Zed_string.t
 
@@ -34,18 +32,15 @@ module UTF8 : Type
   with type char_intf= Zed_utf8.t
   and type string_intf= Zed_utf8.t =
 struct
-  module Zed_char_UTF8 = Zed_char.US(UTF8)
-  module Zed_string_UTF8 = Zed_string.US(UTF8)
-
   type char_intf= Zed_utf8.t
   type string_intf= Zed_utf8.t
 
   let empty_string ()= ""
   let of_char= Zed_char.to_utf8
   let of_string= Zed_string.to_utf8
-  let to_char= Zed_char_UTF8.to_t
-  let to_string= Zed_string_UTF8.to_t
-  let to_char_exn= Zed_char_UTF8.to_t_exn
-  let to_string_exn= Zed_string.unsafe_of_utf8
+  let to_char x = Zed_char.of_uChars (Zed_utf8.explode x)
+  let to_string x = Zed_string.of_uChars (Zed_utf8.explode x)
+  let to_char_exn x = match to_char x with Some t, _ -> t | _ -> failwith "to_t_exn"
+  let to_string_exn = Zed_string.unsafe_of_utf8
 end
 
